@@ -6,7 +6,7 @@ use base 'Exporter';
 
 use Mac::FSEvents::Event;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 our @EXPORT_OK   = qw(NONE WATCH_ROOT);
 our %EXPORT_TAGS = ( flags => \@EXPORT_OK );
@@ -16,10 +16,14 @@ my @maybe_export_ok = qw(IGNORE_SELF FILE_EVENTS);
 require XSLoader;
 XSLoader::load('Mac::FSEvents', $VERSION);
 
+my %const_args;
+
 # generate subs for each constant
 foreach my $constant ( @EXPORT_OK ) {
     my ( undef, $value ) = constant($constant);
 
+    $const_args{ lc $constant } = $value if $constant ne "NONE";
+
     no strict 'refs';
     *$constant = sub {
         return $value;
@@ -31,6 +35,8 @@ foreach my $constant ( @maybe_export_ok ) {
     my ( undef, $value ) = constant($constant);
 
     if ( defined($value) ) {
+        $const_args{ lc $constant } = $value;
+
         no strict 'refs';
         *$constant = sub {
             return $value;
@@ -41,20 +47,44 @@ foreach my $constant ( @maybe_export_ok ) {
 
 sub new {
     my $self = shift;
-    my $args = shift;
+
+    my $args;
+    if ( @_ == 1 && ref $_[0] eq 'HASH' ) {
+        $args = shift;
+    }
+    elsif ( @_ == 1 ) {
+        $args = { path => shift };
+    }
+    else {
+        $args = { @_ };
+    }
 
     die "path argument to new() must be supplied" unless $args->{path};
-    die "path argument to new() must be plain string" if ref $args->{path};
+    die "path argument to new() must be plain string or arrayref"
+        if ref $args->{path} and ref $args->{path} ne 'ARRAY';
+
+    # Build the flags
+    for my $const_name ( keys %const_args ) {
+        if ( $args->{ $const_name } ) {
+            $args->{flags} |= $const_args{ $const_name };
+            delete $args->{ $const_name };
+        }
+    }
+
+    # Normalize path to arrayref
+    if ( !ref $args->{path} ) {
+        $args->{path} = [ $args->{path} ];
+    }
 
     return __PACKAGE__->_new( $args );
 }
 
 sub DESTROY {
     my $self = shift;
-    
+
     # Make sure thread has stopped
     $self->stop;
-    
+
     # C cleanup
     $self->_DESTROY();
 }
@@ -69,14 +99,18 @@ Mac::FSEvents - Monitor a directory structure for changes
 =head1 SYNOPSIS
 
   use Mac::FSEvents;
-  # or use Mac::FSEvents qw(:flags);
 
-  my $fs = Mac::FSEvents->new( {
-      path    => '/',       # required, the path to watch
-      latency => 2.0,       # optional, time to delay before returning events
-      since   => 451349510, # optional, return events from this eventId
-      flags   => NONE,      # optional, set stream creation flags
-  } );
+  my $fs = Mac::FSEvents->new(
+      path          => '/',         # required, the path(s) to watch
+                                    # optionally specify an arrayref of multiple paths
+      latency       => 2.0,         # optional, time to delay before returning events
+      since         => 451349510,   # optional, return events from this eventId
+      watch_root    => 1,           # optional, fire events if the watched path changes
+      ignore_self   => 1,           # optional, ignore events from this process
+      file_events   => 1,           # optional, fire events on files instead of dirs
+  );
+  ### OR
+  my $fs = Mac::FSEvents->new( '/' ); # Only specify the path
 
   my $fh = $fs->watch;
 
@@ -111,14 +145,18 @@ Event monitoring occurs in a separate C thread from the rest of your application
 
 =item B<new> ( { ARGUMENTS } )
 
-Create a new watcher.  A hash reference containing arguments is required:
+=item B<new> ( ARGUMENTS )
+
+=item B<new> ( PATH )
+
+Create a new watcher. C<ARGUMENTS> is a hash or hash reference with the following keys:
 
 =over 8
 
 =item path
 
-Required.  The full path to the directory to watch.  All subdirectories beneath
-this directory are watched.
+Required. A plain string or arrayref of strings of directories to watch. All
+subdirectories beneath these directories are watched.
 
 =item latency
 
@@ -135,28 +173,57 @@ Optional.  A previously obtained event ID may be passed as the since argument.
 notification will be sent for every event that has happened since that ID.  This can
 be useful for seeing what has changed while your program was not running.
 
+=item ignore_self
+
+(Only available on OS X 10.6 or greater)
+
+Don't send events triggered by the current process. Useful if you are also modifying
+files in the watch list.
+
+=item file_events
+
+(Only available on OS X 10.7 or greater)
+
+Send events for files. By default, only directory-level events are generated,
+and may be coelesced if they happen simultaneously. With this flag, an event
+will be generated for every change to a file.
+
+=item watch_root
+
+Request notifications if the location of the paths being watched change. For example,
+if there is a watch for C</foo/bar>, and it is renamed to C</foo/buzz>, an event will
+be generated with the C<root_changed> flag set.
+
 =item flags
 
 Optional.  Sets the flags provided to L<FSEventStreamCreate>.  In order to
 import the flag constants, you must provide C<:flags> to C<use Mac::FSEvents>.
+
+This method of setting flags is discouraged in favor of using the constructor argument,
+above.
+
 The following flags are supported:
 
 =over 8
 
 =item NONE
 
+No flags. The default.
+
 =item WATCH_ROOT
 
-=item IGNORE_SELF (Only available on OS X 10.6 or greater)
+Set by the C<watch_root> constructor argument.
 
-=item FILE_EVENTS (Only available on OS X 10.7 or greater)
+=item IGNORE_SELF
+
+Set by the C<ignore_self> constructor argument.
+
+=item FILE_EVENTS
+
+Set by the C<file_events> constructor argument.
 
 =back
 
-Consult the FSEvents documentation for what these flags do.
-
-Default: NONE
-
 =back
 
 =item B<watch>
@@ -172,6 +239,10 @@ this method will block until an event is available.
 
 Events are returned as L<Mac::FSEvents::Event> objects.
 
+B<NOTE:> Event paths are real file system paths, with all the symbolic links
+resolved. If you are watching a path with a symbolic link, use L<Cwd/abs_path>
+if you need to make comparisons against the event's path.
+
 =item B<stop>
 
 Stop watching.
